==> blancoPdf-0.1.8-src.zip: blancoPdf/blanco/main/blanco/sample/pdf/report/items/Yoko01PdfReportBlockItems.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.sample.pdf.report.items;

/**
 * PDF ڌQB
 */
public class Yoko01PdfReportBlockItems {
    /**
     * tB[h: [Block01]B
     */
    private String fBlock01;

    /**
     * tB[h: [Block02]B
     */
    private String fBlock02;

    /**
     * tB[h: [Block03]B
     */
    private String fBlock03;

    /**
     * tB[h: [Block04]B
     */
    private String fBlock04;

    /**
     * tB[h [Block01] ̒lݒ肵܂B
     *
     * @param argBlock01 tB[h[Block01]ɐݒ肷lB
     */
    public void setBlock01(final String argBlock01) {
        fBlock01 = argBlock01;
    }

    /**
     * tB[h [Block01] ̒l擾܂B
     *
     * @return tB[h[Block01]擾lB
     */
    public String getBlock01() {
        return fBlock01;
    }

    /**
     * tB[h [Block02] ̒lݒ肵܂B
     *
     * @param argBlock02 tB[h[Block02]ɐݒ肷lB
     */
    public void setBlock02(final String argBlock02) {
        fBlock02 = argBlock02;
    }

    /**
     * tB[h [Block02] ̒l擾܂B
     *
     * @return tB[h[Block02]擾lB
     */
    public String getBlock02() {
        return fBlock02;
    }

    /**
     * tB[h [Block03] ̒lݒ肵܂B
     *
     * @param argBlock03 tB[h[Block03]ɐݒ肷lB
     */
    public void setBlock03(final String argBlock03) {
        fBlock03 = argBlock03;
    }

    /**
     * tB[h [Block03] ̒l擾܂B
     *
     * @return tB[h[Block03]擾lB
     */
    public String getBlock03() {
        return fBlock03;
    }

    /**
     * tB[h [Block04] ̒lݒ肵܂B
     *
     * @param argBlock04 tB[h[Block04]ɐݒ肷lB
     */
    public void setBlock04(final String argBlock04) {
        fBlock04 = argBlock04;
    }

    /**
     * tB[h [Block04] ̒l擾܂B
     *
     * @return tB[h[Block04]擾lB
     */
    public String getBlock04() {
        return fBlock04;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.sample.pdf.report.items.Yoko01PdfReportBlockItems[");
        buf.append("Block01=" + fBlock01);
        buf.append(",Block02=" + fBlock02);
        buf.append(",Block03=" + fBlock03);
        buf.append(",Block04=" + fBlock04);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoPdf-0.2.5-src.zip: blancoPdf/blanco/main/blanco/sample/pdf/report/items/Yoko01PdfReportBlockItems.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.sample.pdf.report.items;

/**
 * PDF ڌQB
 */
public class Yoko01PdfReportBlockItems {
    /**
     * PDF o͂̂߂̓ǗC[B
     *
     * tB[h: [Layer]B
     * ftHg: [0]B
     */
    private int fLayer = 0;

    /**
     * tB[h: [Block01]B
     */
    private String fBlock01;

    /**
     * tB[h: [Gokei01]B
     */
    private String fGokei01;

    /**
     * tB[h: [Block02]B
     */
    private String fBlock02;

    /**
     * tB[h: [Block03]B
     */
    private String fBlock03;

    /**
     * tB[h: [Block04]B
     */
    private String fBlock04;

    /**
     * tB[h [Layer] ̒lݒ肵܂B
     *
     * tB[h̐: [PDF o͂̂߂̓ǗC[B]B
     *
     * @param argLayer tB[h[Layer]ɐݒ肷lB
     */
    public void setLayer(final int argLayer) {
        fLayer = argLayer;
    }

    /**
     * tB[h [Layer] ̒l擾܂B
     *
     * tB[h̐: [PDF o͂̂߂̓ǗC[B]B
     * ftHg: [0]B
     *
     * @return tB[h[Layer]擾lB
     */
    public int getLayer() {
        return fLayer;
    }

    /**
     * tB[h [Block01] ̒lݒ肵܂B
     *
     * @param argBlock01 tB[h[Block01]ɐݒ肷lB
     */
    public void setBlock01(final String argBlock01) {
        fBlock01 = argBlock01;
    }

    /**
     * tB[h [Block01] ̒l擾܂B
     *
     * @return tB[h[Block01]擾lB
     */
    public String getBlock01() {
        return fBlock01;
    }

    /**
     * tB[h [Gokei01] ̒lݒ肵܂B
     *
     * @param argGokei01 tB[h[Gokei01]ɐݒ肷lB
     */
    public void setGokei01(final String argGokei01) {
        fGokei01 = argGokei01;
    }

    /**
     * tB[h [Gokei01] ̒l擾܂B
     *
     * @return tB[h[Gokei01]擾lB
     */
    public String getGokei01() {
        return fGokei01;
    }

    /**
     * tB[h [Block02] ̒lݒ肵܂B
     *
     * @param argBlock02 tB[h[Block02]ɐݒ肷lB
     */
    public void setBlock02(final String argBlock02) {
        fBlock02 = argBlock02;
    }

    /**
     * tB[h [Block02] ̒l擾܂B
     *
     * @return tB[h[Block02]擾lB
     */
    public String getBlock02() {
        return fBlock02;
    }

    /**
     * tB[h [Block03] ̒lݒ肵܂B
     *
     * @param argBlock03 tB[h[Block03]ɐݒ肷lB
     */
    public void setBlock03(final String argBlock03) {
        fBlock03 = argBlock03;
    }

    /**
     * tB[h [Block03] ̒l擾܂B
     *
     * @return tB[h[Block03]擾lB
     */
    public String getBlock03() {
        return fBlock03;
    }

    /**
     * tB[h [Block04] ̒lݒ肵܂B
     *
     * @param argBlock04 tB[h[Block04]ɐݒ肷lB
     */
    public void setBlock04(final String argBlock04) {
        fBlock04 = argBlock04;
    }

    /**
     * tB[h [Block04] ̒l擾܂B
     *
     * @return tB[h[Block04]擾lB
     */
    public String getBlock04() {
        return fBlock04;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.sample.pdf.report.items.Yoko01PdfReportBlockItems[");
        buf.append("Layer=" + fLayer);
        buf.append(",Block01=" + fBlock01);
        buf.append(",Gokei01=" + fGokei01);
        buf.append(",Block02=" + fBlock02);
        buf.append(",Block03=" + fBlock03);
        buf.append(",Block04=" + fBlock04);
        buf.append("]");
        return buf.toString();
    }
}
